==> owlexplanation-1.0.2-sources.jar: org/semanticweb/owl/explanation/impl/blackbox/ExpansionStrategy.java <==
package org.semanticweb.owl.explanation.impl.blackbox;

import org.semanticweb.owl.explanation.api.ExplanationProgressMonitor;
import org.semanticweb.owlapi.model.OWLAxiom;
import org.semanticweb.owlapi.model.OWLException;

import java.util.Set;

/*
 * Copyright (C) 2008, University of Manchester
 *
 * Modifications to the initial code base are copyright of their
 * respective authors, or their employers as appropriate.  Authorship
 * of the modifications may be determined from the ChangeLog placed at
 * the end of this file.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */


/**
 * Author: Matthew Horridge<br> The University Of Manchester<br> Information Management Group<br> Date:
 * 03-Sep-2008<br><br>
 */
public interface ExpansionStrategy {

    /**
     * Given an input set of axioms, returns a subset of axioms in which the entailment holds, or the empty set
     * if the entailment does not hold in the input set.
     * @param axioms The input set.  The entailment may or may not hold in this set.
     * @param checker The entailment checker that should be used to check for entailment at
     * each stage.
     * @param progressMonitor
     * @return A set of axioms that the entailment holds in, or the empty set if the entailment does not hold in the
     * input set.
     */
    Set<OWLAxiom> doExpansion(Set<OWLAxiom> axioms, EntailmentChecker checker, ExplanationProgressMonitor<?> progressMonitor);

    int getNumberOfSteps();
}

==> owlexplanation-2.0.0-sources.jar: org/semanticweb/owl/explanation/impl/blackbox/ExpansionStrategy.java <==
package org.semanticweb.owl.explanation.impl.blackbox;

import org.semanticweb.owl.explanation.api.ExplanationProgressMonitor;
import org.semanticweb.owlapi.model.OWLAxiom;
import org.semanticweb.owlapi.model.OWLException;

import java.util.Set;

/*
 * Copyright (C) 2008, University of Manchester
 *
 * Modifications to the initial code base are copyright of their
 * respective authors, or their employers as appropriate.  Authorship
 * of the modifications may be determined from the ChangeLog placed at
 * the end of this file.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */


/**
 * Author: Matthew Horridge<br> The University Of Manchester<br> Information Management Group<br> Date:
 * 03-Sep-2008<br><br>
 */
public interface ExpansionStrategy {

    /**
     * Given an input set of axioms, returns a subset of axioms in which the entailment holds, or the empty set
     * if the entailment does not hold in the input set.
     * @param axioms The input set.  The entailment may or may not hold in this set.
     * @param checker The entailment checker that should be used to check for entailment at
     * each stage.
     * @param progressMonitor A progress monitor.  Not {@code null}.
     * @return A set of axioms that the entailment holds in, or the empty set if the entailment does not hold in the
     * input set.
     */
    Set<OWLAxiom> doExpansion(Set<OWLAxiom> axioms, EntailmentChecker checker, ExplanationProgressMonitor<?> progressMonitor);

    int getNumberOfSteps();
}
